pub struct DetectCaptchaResult {
pub kind: Option<String>,
}Fields
kind: Option<String>Trait Implementations
Sourceimpl Debug for DetectCaptchaResult
impl Debug for DetectCaptchaResult
Sourceimpl JsonSchema for DetectCaptchaResult
impl JsonSchema for DetectCaptchaResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DetectCaptchaResult
impl RefUnwindSafe for DetectCaptchaResult
impl Send for DetectCaptchaResult
impl Sync for DetectCaptchaResult
impl Unpin for DetectCaptchaResult
impl UnsafeUnpin for DetectCaptchaResult
impl UnwindSafe for DetectCaptchaResult