pub struct ExtractResult {
pub texts: Vec<String>,
}Fields
texts: Vec<String>Trait Implementations
Sourceimpl Debug for ExtractResult
impl Debug for ExtractResult
Sourceimpl JsonSchema for ExtractResult
impl JsonSchema for ExtractResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ExtractResult
impl RefUnwindSafe for ExtractResult
impl Send for ExtractResult
impl Sync for ExtractResult
impl Unpin for ExtractResult
impl UnsafeUnpin for ExtractResult
impl UnwindSafe for ExtractResult