pub struct NetworkCaptureResult {
pub entries: Vec<NetworkEntry>,
}Fields
entries: Vec<NetworkEntry>Trait Implementations
Sourceimpl Debug for NetworkCaptureResult
impl Debug for NetworkCaptureResult
Sourceimpl JsonSchema for NetworkCaptureResult
impl JsonSchema for NetworkCaptureResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for NetworkCaptureResult
impl RefUnwindSafe for NetworkCaptureResult
impl Send for NetworkCaptureResult
impl Sync for NetworkCaptureResult
impl Unpin for NetworkCaptureResult
impl UnsafeUnpin for NetworkCaptureResult
impl UnwindSafe for NetworkCaptureResult