pub struct NetworkEntry {
pub url: String,
pub initiator_type: String,
pub transfer_size: f64,
pub duration_ms: f64,
}Fields
url: Stringinitiator_type: Stringtransfer_size: f64duration_ms: f64Trait Implementations
Sourceimpl Debug for NetworkEntry
impl Debug for NetworkEntry
Sourceimpl JsonSchema for NetworkEntry
impl JsonSchema for NetworkEntry
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for NetworkEntry
impl RefUnwindSafe for NetworkEntry
impl Send for NetworkEntry
impl Sync for NetworkEntry
impl Unpin for NetworkEntry
impl UnsafeUnpin for NetworkEntry
impl UnwindSafe for NetworkEntry