pub struct TypeTextArgs {
pub session_id: String,
pub selector: Option<String>,
pub text: String,
}Fields
session_id: Stringselector: Option<String>CSS selector of the target input. When omitted, keys are dispatched to whatever currently has focus.
text: StringTrait Implementations
Sourceimpl Debug for TypeTextArgs
impl Debug for TypeTextArgs
Sourceimpl Default for TypeTextArgs
impl Default for TypeTextArgs
Sourcefn default() -> TypeTextArgs
fn default() -> TypeTextArgs
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for TypeTextArgs
impl<'de> Deserialize<'de> for TypeTextArgs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TypeTextArgs
impl JsonSchema for TypeTextArgs
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TypeTextArgs
impl RefUnwindSafe for TypeTextArgs
impl Send for TypeTextArgs
impl Sync for TypeTextArgs
impl Unpin for TypeTextArgs
impl UnsafeUnpin for TypeTextArgs
impl UnwindSafe for TypeTextArgs