pub struct FetchManyItem {
pub ok: bool,
pub result: Option<FetchResult>,
pub error: Option<String>,
}Fields
ok: boolresult: Option<FetchResult>error: Option<String>Trait Implementations
Sourceimpl Debug for FetchManyItem
impl Debug for FetchManyItem
Sourceimpl JsonSchema for FetchManyItem
impl JsonSchema for FetchManyItem
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for FetchManyItem
impl RefUnwindSafe for FetchManyItem
impl Send for FetchManyItem
impl Sync for FetchManyItem
impl Unpin for FetchManyItem
impl UnsafeUnpin for FetchManyItem
impl UnwindSafe for FetchManyItem