pub struct FetchManyResult {
pub results: Vec<FetchManyItem>,
pub pool: PoolMeta,
}Fields
results: Vec<FetchManyItem>pool: PoolMetaTrait Implementations
Sourceimpl Debug for FetchManyResult
impl Debug for FetchManyResult
Sourceimpl JsonSchema for FetchManyResult
impl JsonSchema for FetchManyResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for FetchManyResult
impl RefUnwindSafe for FetchManyResult
impl Send for FetchManyResult
impl Sync for FetchManyResult
impl Unpin for FetchManyResult
impl UnsafeUnpin for FetchManyResult
impl UnwindSafe for FetchManyResult