pub struct SessionCloseResult {
pub closed: bool,
}Fields
closed: boolTrait Implementations
Sourceimpl Debug for SessionCloseResult
impl Debug for SessionCloseResult
Sourceimpl JsonSchema for SessionCloseResult
impl JsonSchema for SessionCloseResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SessionCloseResult
impl RefUnwindSafe for SessionCloseResult
impl Send for SessionCloseResult
impl Sync for SessionCloseResult
impl Unpin for SessionCloseResult
impl UnsafeUnpin for SessionCloseResult
impl UnwindSafe for SessionCloseResult