pub struct SessionContentResult {
pub url: Option<String>,
pub title: Option<String>,
pub html: String,
}Fields
url: Option<String>title: Option<String>html: StringTrait Implementations
Sourceimpl Debug for SessionContentResult
impl Debug for SessionContentResult
Sourceimpl JsonSchema for SessionContentResult
impl JsonSchema for SessionContentResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SessionContentResult
impl RefUnwindSafe for SessionContentResult
impl Send for SessionContentResult
impl Sync for SessionContentResult
impl Unpin for SessionContentResult
impl UnsafeUnpin for SessionContentResult
impl UnwindSafe for SessionContentResult