pub struct SessionIdArgs {
pub session_id: String,
}Fields
session_id: StringTrait Implementations
Sourceimpl Debug for SessionIdArgs
impl Debug for SessionIdArgs
Sourceimpl Default for SessionIdArgs
impl Default for SessionIdArgs
Sourcefn default() -> SessionIdArgs
fn default() -> SessionIdArgs
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for SessionIdArgs
impl<'de> Deserialize<'de> for SessionIdArgs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SessionIdArgs
impl JsonSchema for SessionIdArgs
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SessionIdArgs
impl RefUnwindSafe for SessionIdArgs
impl Send for SessionIdArgs
impl Sync for SessionIdArgs
impl Unpin for SessionIdArgs
impl UnsafeUnpin for SessionIdArgs
impl UnwindSafe for SessionIdArgs