pub struct SessionOpenResult {
pub session_id: String,
}Fields
session_id: StringTrait Implementations
Sourceimpl Debug for SessionOpenResult
impl Debug for SessionOpenResult
Sourceimpl JsonSchema for SessionOpenResult
impl JsonSchema for SessionOpenResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SessionOpenResult
impl RefUnwindSafe for SessionOpenResult
impl Send for SessionOpenResult
impl Sync for SessionOpenResult
impl Unpin for SessionOpenResult
impl UnsafeUnpin for SessionOpenResult
impl UnwindSafe for SessionOpenResult